#' Read gene summary file in MAGeCK-RRA results
#'
#' @docType methods
#' @name ReadRRA
#' @rdname ReadRRA
#' @aliases readrra
#'
#' @param gene_summary A file path or a data frame of gene summary data
#' generated by command `mageck test`.
#'
#' @return A data frame including four columns, named "Official", "EntrezID", "LFC" and "FDR".
#'
#' @author Wubing Zhang
#'
#'
#' @examples
#' data(rra.gene_summary)
#' dd.rra = ReadRRA(rra.gene_summary)
#' head(dd.rra)
#'
#' @export
#'

ReadRRA <- function(gene_summary){
  message(Sys.time(), " # Read gene summary file ...")
  if(is.character(gene_summary) && file.exists(gene_summary)){
    dd = read.table(file = gene_summary, header = TRUE)
    dd = dd[, c("id", "neg.goodsgrna", "neg.lfc", "neg.fdr", "pos.goodsgrna","pos.fdr")]
  }else if(is.data.frame(gene_summary) &&
           all(c("id", "neg.goodsgrna", "neg.lfc", "neg.fdr",
                 "pos.goodsgrna","pos.fdr") %in%
               colnames(gene_summary))){
    dd = gene_summary[, c("id", "neg.goodsgrna", "neg.lfc", "neg.fdr", "pos.goodsgrna","pos.fdr")]
  }else{
    stop("The parameter gene_summary is below standard!")
  }
  dd$LFC = dd$neg.lfc
  dd$FDR = apply(dd[, 2:6], 1, function(x) {
    ifelse((max(x[c(1, 4)])>1) & (x[1]>x[4]), x[3], x[5])})
  dd = dd[, c("id", "LFC", "FDR")]
  colnames(dd)[1] = "Official"
  # rownames(dd) = dd$EntrezID
  return(dd)
}
