% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/FluteMLE.R
\docType{methods}
\name{FluteMLE}
\alias{FluteMLE}
\alias{flutemle}
\title{Downstream analysis based on MAGeCK-MLE result}
\usage{
FluteMLE(gene_summary, ctrlname, treatname, keytype = "Symbol",
  organism = "hsa", scale_cutoff = 2, top = 10, bottom = 10,
  interestGenes = NA, limit = c(1, 120), pvalueCutoff = 0.25,
  enrich_kegg = "ORT", posControl = NULL, loess = FALSE,
  prefix = "", width = 10, height = 7, outdir = ".",
  view_allpath = FALSE)
}
\arguments{
\item{gene_summary}{A data frame, which contains columns of 'Gene',
\code{ctrlname}.beta and \code{treatname}.beta.}

\item{ctrlname}{A character vector, specifying the names of control samples.}

\item{treatname}{A character vector, specifying the names of treatment samples.}

\item{keytype}{"Entrez" or "Symbol".}

\item{organism}{"hsa" or "mmu".}

\item{scale_cutoff}{Boolean or numeric, whether scale cutoff to whole genome level,
or how many standard deviation will be used as cutoff.}

\item{top}{An integer, specifying number of top selected genes to be labeled in rank figure.}

\item{bottom}{An integer, specifying number of bottom selected genes to be labeled in rank figure.}

\item{interestGenes}{A character vector, specifying interested genes to be labeled in rank figure.}

\item{limit}{A two-length vector (default: c(1, 120)), specifying the minimal and
maximal size of gene sets for enrichent analysis.}

\item{pvalueCutoff}{A numeric, specifying pvalue cutoff of enrichment analysis, default 1.}

\item{enrich_kegg}{One of "ORT"(Over-Representing Test), "GSEA"(Gene Set Enrichment Analysis), and "HGT"(HyperGemetric test).}

\item{posControl}{A character vector, specifying a list of positive control gene symbols.}

\item{loess}{Boolean, whether include loess normalization in the pipeline.}

\item{prefix}{A character, indicating the prefix of output file name, which can't contain special characters.}

\item{width}{The width of summary pdf in inches.}

\item{height}{The height of summary pdf in inches.}

\item{outdir}{Output directory on disk.}

\item{view_allpath}{Boolean, whether output all pathway view figures.}
}
\value{
All of the pipeline results is output into the \code{out.dir}/\code{prefix}_Results,
which includes a pdf file and many folders. The pdf file '{prefix}_Pipeline_results.pdf' is the
summary of pipeline results. For each section in this pipeline, figures and useful data are
outputed to corresponding subfolders.
\itemize{
  \item {Distribution_of_BetaScores}: {Density plot and violin plot of beta scores.}
  \item {MAplot}: {Maplot for each normalized data.}
  \item {Linear_Fitting_of_BetaScores}: {Linear fitting of beta scores indicates the difference of cell cycle
  time between Control and Treatment samples.}
  \item {Scatter_Treat_Ctrl}: {Positive selection and negative selection.}
  \item {Enrichment_Treat-Ctrl}: {Enrichment analysis for positive and negative selection genes.}
  \item {Pathview_Treat_Ctrl}: {Pathway view for top enriched pathways.}
  \item {Scatter_9Square}: {Using 9 Square to select drug related genes.}
  \item {Enrichment_9Square}: {Enrichment analysis for selected genes.}
  \item {Pathview_9Square}: {Pathway view for top enriched pathways.}
}
}
\description{
Integrative analysis pipeline using the gene summary table in MAGeCK MLE results
}
\details{
MAGeCK-MLE can be used to analyze screen data from multi-conditioned experiments. MAGeCK-MLE
also normalizes the data across multiple samples, making them comparable to each other. The most important
ouput of MAGeCK MLE is `gene_summary` file, which includes the beta scores of multiple conditions and
the associated statistics. The `beta score`  for each gene describes how the gene is selected: a positive
beta score indicates a positive selection, and a negative beta score indicates a negative selection.

The downstream analysis includes identifying essential, non-essential, and target-associated genes,
and performing biological functional category analysis and pathway enrichment analysis of these genes.
The function also visualizes genes in the context of pathways to benefit users exploring screening data.
}
\examples{
data(mle.gene_summary)
\dontrun{
  # functional analysis for MAGeCK MLE results
  FluteMLE(mle.gene_summary, ctrlname = "dmso", treatname = "plx",
           prefix = "PLX", pvalueCutoff = 0.25, organism = "hsa")
}

}
\seealso{
\code{\link{FluteRRA}}
}
\author{
Wubing Zhang
}
